/*******************************************************************************

WePhoto - Photo viewer for multi-touch devices
Copyright (C) 2010 Mihai Paslariu
Original Name MihPhoto
Adapted for WeTab 2011 by Peter Herzog www.pherzog.net

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

*******************************************************************************/

#define __CONFIGURATION_MAIN__
#include "Config.h"

#include <QDir>
#include <QFile>
#include <QTextStream>
#include <stdio.h>
#include <QtCore>

Config::Config()
{
	background.setRgb(0,0,0);
	drag_sensitivity = 30;
	dragspeed = 400;
	flip_distance = 40;
	min_zoom = 0.1;
	show_file_name = true;
	install_dir = ".";
	rotate_by_exif = true;
	zoom_speed = 0.8;
	allow_rotation = true;
	last_open_dir = "";
	multitouch = true;
	max_zoom = 10.0;

	// try to guess the default image folder
	last_open_dir = QDir::homePath() ;
	last_open_dir = last_open_dir + "/Fotos und Videos";
	if ( !_dirExists(last_open_dir) )
		last_open_dir = QDir::homePath();

	double_click_fullscreen = true;
}

// for saving and loading, the name of the key is the
// same as the name of the variable

bool Config::save()
{
	QString filename = QDir::homePath() + "/" + CONFIG_FILE;

	// save configuration to file
	QFile f(filename);

	if ( f.open(QIODevice::WriteOnly|QIODevice::Truncate|QIODevice::Text) )
	{
		QTextStream ts(&f);
		ts << "background = " << _fromColor(background) << "\n";
		ts << "drag_sensitivity = " << drag_sensitivity << "\n";
		ts << "flip_distance = " << flip_distance << "\n";
		ts << "min_zoom = " << min_zoom << "\n";
		ts << "max_zoom = " << max_zoom << "\n";
		ts << "show_file_name = " << _fromBool(show_file_name) << "\n";
		ts << "rotate_by_exif = " << _fromBool(rotate_by_exif) << "\n";
		ts << "allow_rotation = " << _fromBool(allow_rotation) << "\n";
		ts << "multitouch = " << _fromBool(multitouch) << "\n";
		ts << "zoom_speed = " << zoom_speed << "\n";
		ts << "double_click_fullscreen = " << _fromBool(double_click_fullscreen) << "\n";
		ts << "last_dir = " << last_open_dir << "\n";
		ts << "dragspeed = " << dragspeed << "\n";

		f.close();
		return true;
	}

	printf("Kann Configdatei nicht speichern %s\n", filename.toUtf8().data());
	return false;
}

bool Config::load()
{
	QString filename = QDir::homePath() + "/" + CONFIG_FILE;

	QFile f(filename);
	if ( f.open(QIODevice::ReadOnly|QIODevice::Text) )
	{
		QTextStream ts(&f);
		while ( !ts.atEnd() )
		{
			QString line = ts.readLine(1024);
			int k = line.indexOf("=");
			if ( k < 0 ) continue;
			QString key = line.mid(0,k).trimmed();
			QString value = line.mid(k+1).trimmed();

			if ( key == "background" )
				background = _toColor(value);
			else if ( key == "drag_sensitivity" )
				drag_sensitivity = value.toInt();
			else if ( key == "dragspeed" )
				dragspeed = value.toInt();
			else if ( key == "flip_distance" )
				flip_distance = value.toInt();
			else if ( key == "min_zoom" )
				min_zoom = value.toDouble();
			else if ( key == "show_file_name" )
				show_file_name = _toBool(value);
			else if ( key == "rotate_by_exif" )
				rotate_by_exif = _toBool(value);
			else if ( key == "allow_rotation" )
				allow_rotation = _toBool(value);

			#ifndef Q_OS_SYMBIAN
			else if ( key == "max_zoom" )
				max_zoom = value.toDouble();
			else if ( key == "multitouch" )
				multitouch = _toBool(value);
			#endif

			else if ( key == "double_click_fullscreen" )
				double_click_fullscreen = _toBool(value);
			else if ( key == "last_dir" )
				last_open_dir = value;
			else if ( key == "zoom_speed" )
			{
				double z = value.toDouble();
				if ( z > 0.01 ) zoom_speed = z ;
			}
			// else => ignore unknown key
			f.close();
		}
		return true;
	}

	printf("Config Datei konnte nicht geladen werden\n");
	return false;
}

QString Config::_fromColor( QColor &c )
{
	QString s;
	s.sprintf("%d %d %d", c.red(), c.green(), c.blue() );
	return s;
}

QColor Config::_toColor( QString &s )
{
	int r,g,b;
	sscanf( s.toAscii().data(), "%d %d %d", &r,&g,&b);
	return QColor(r,g,b);
}

QString Config::_fromBool( bool b )
{
	return b ? "true" : "false";
}

bool Config::_toBool( QString &s )
{
	QString s1 = s.toLower();
	return s == "yes" || s == "true";
}

bool Config::_dirExists( QString s )
{
	QDir d(s);
	return d.exists();
}
