/*******************************************************************************

WePhoto - Photo viewer for multi-touch devices
Copyright (C) 2010 Mihai Paslariu
Original Name MihPhoto
Adapted for WeTab 2011 by Peter Herzog www.pherzog.net

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

*******************************************************************************/

#ifndef __IMAGE_AREA_H__
#define __IMAGE_AREA_H__

#include <QColor>
#include <QImage>
#include <QPoint>
#include <QWidget>
#include <QTimer>
#include <QDateTime>
#include <QTouchEvent>

#include "ImageLoadThread.h"
#include "TouchUI.h"

class ImageArea : public QWidget
{
Q_OBJECT

private:

	int _drag_offset;
	QStringList _files;
	int _current_index;

	QImage * _previous, * _current, * _next;
	double _previous_zoom, _current_zoom, _next_zoom;
	int _posx,_posy;
	double _rotation;
	bool _show_ui;

	int _initial_posx,_initial_posy,_initial_drag_offset;
	double _initial_rotation,_initial_zoom;
	bool _allow_zoom,_allow_pan,_allow_drag;
	bool _two_fingers;
	bool _changing;
	QTimer _timer;
	ImageLoadThread _load_thread;

	TouchUI _ui;
	QImage _zoom_in_icon,_zoom_out_icon,_zoom_indicator;

	// only for mouse mode
	int _mouse_start_x;
	int _mouse_start_y;
	bool _mouse_drag;

public:

	ImageArea( QWidget *parent = 0 );
	~ImageArea( void );

public:

	void setFiles( QStringList files, QString current );

public slots:

	void forward( void );
	void back( void );
	void first( void );
	void last( void );
	void changeUI( void );
	void zoomIn( double speed = 0 );
	void zoomOut( double speed = 0 );
	void zoomToFit( void );
	void zoomToOriginalSize( void );
	void rotateLeft( void );
	void rotateRight( void );
	void moveView( int deltax, int deltay );

protected:

	void paintEvent(QPaintEvent *event);
	void resizeEvent(QResizeEvent *event);
	bool event(QEvent *event);

	bool event_multitouch(QEvent *event);
	bool event_singletouch(QEvent *event);

	void onPan( const QTouchEvent::TouchPoint & point, bool end );
	void onTwoFingers( const QTouchEvent::TouchPoint tp0,
		const QTouchEvent::TouchPoint tp1 );

	void onTap( int x, int y );

protected slots:

	void onTimer( void );

signals:

	void closeOnTouch( void );
	void changeFullscreen( void );
	void loadFile( void );

private:

	void _resetTouchParams( void );
	void _loadImage( int k, QImage ** dest, double * zoom_dest );
	double _computeFitZoom( QImage * img );
	double _computeFitZoomWithRotation( QImage * img );
	void _moveForward( void );
	void _moveBack( void );
	void _reloadAll( void );
	void _handleTouchAction( TouchUIAction action );
	void _limitZoom( double & zoom );
	void _limitPan( void );
	QTransform _getCurrentTransform( void );

};

#endif
