/*******************************************************************************

WePhoto - Photo viewer for multi-touch devices
Copyright (C) 2010 Mihai Paslariu
Original Name MihPhoto
Adapted for WeTab 2011 by Peter Herzog www.pherzog.net

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

*******************************************************************************/

#ifndef __IMAGE_LOAD_THREAD_H__
#define __IMAGE_LOAD_THREAD_H__

#include <QThread>
#include "ThreadSafeQueue.h"
#include <QImage>

struct ImageLoadItem
{
	QString name;
	QImage ** destination;
	double * zoom;
	int w,h;
};

class ImageLoadThread : public QThread
{
Q_OBJECT

private:

	ThreadSafeQueue<ImageLoadItem> _in;
	int _load;
	QMutex _load_mutex;

	volatile bool _finished;

public:

	ImageLoadThread( void ) : QThread()
	{
		_finished = false;
		_load = 0;
	}

public:

	void run();

private:

	QImage * _loadImage( QString name, int area_width, int area_height );
	double _computeFitZoom( QImage * img, int w, int h );
	qreal _getExifRotation( QString fullname );

public:

	inline ThreadSafeQueue<ImageLoadItem> & getQueue( void )
	{
		return _in;
	}

	inline void addLoadImage( ImageLoadItem & ili )
	{
		_load_mutex.lock();
		_load++;
		_load_mutex.unlock();
		_in.push( ili );
	}

	inline bool isIdle( void )
	{
		_load_mutex.lock();
		int k = _load;
		_load_mutex.unlock();
		return k == 0;
	}

	inline void stopThread( void )
	{
		_finished = true;
		ImageLoadItem ili;
		ili.destination = NULL;
		ili.zoom = NULL;
		ili.w = ili.h = 0.0;
		_in.push(ili);
	}
};

#endif
