/*******************************************************************************

WePhoto - Photo viewer for multi-touch devices
Copyright (C) 2010 Mihai Paslariu
Original Name MihPhoto
Adapted for WeTab 2011 by Peter Herzog www.pherzog.net

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

*******************************************************************************/

#ifndef __TOUCH_UI_H__
#define __TOUCH_UI_H__

#include <QPainter>
#include <QString>
#include <QImage>
#include <QVector>

enum TouchUIAction
{
	TOUCH_ACTION_NONE,
	TOUCH_ACTION_EXIT,
	TOUCH_ACTION_FULLSCREEN,

	TOUCH_ACTION_ZOOM_IN,
	TOUCH_ACTION_ZOOM_OUT,
	TOUCH_ACTION_ZOOM_FIT,
	TOUCH_ACTION_ZOOM_ORIGINAL,
	TOUCH_ACTION_ROTATE_LEFT,
	TOUCH_ACTION_ROTATE_RIGHT,

	TOUCH_ACTION_GO_FIRST,
	TOUCH_ACTION_GO_LAST,
	TOUCH_ACTION_GO_NEXT,
	TOUCH_ACTION_GO_PREVIOUS,
	TOUCH_ACTION_OPEN
};

struct TouchUIItem
{
	TouchUIAction action;
	int x1,y1,x2,y2;
	QImage image;
};

class TouchUI
{
private:

	QVector<TouchUIItem*> _items;
	QPixmap _background;
	int _xoffset,_yoffset; // currently not used

public:

	TouchUI();
	~TouchUI();

public:

	void draw( QPainter & painter );
	TouchUIAction getAction( int x, int y );
	void addAction( TouchUIAction a, QString icon_name );
	void addSeparator( void );
	
public:

	inline QPixmap * getBackground( void )
	{
		return &_background;
	}
};

#endif
